@@ -118,7 +118,7 @@ def copyright_text():
     return """
 Git Cola: The highly caffeinated Git GUI
 
-Copyright (C) 2007-2016 David Aguilar and contributors
+Copyright (C) 2007-2017 David Aguilar and contributors
 
 This program is free software: you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -141,6 +141,7 @@ If not, see http://www.gnu.org/licenses/.
 def version_text():
     git_version = version.git_version()
     cola_version = version.version()
+    build_version = version.build_version()
     python_path = sys.executable
     python_version = sys.version
     qt_version = qtpy.QT_VERSION
@@ -155,9 +156,15 @@ def version_text():
 
     platform_version = platform.platform()
 
+    # Only show the build version if _build_version.py exists
+    if build_version:
+        build_version = '(%s)' % build_version
+    else:
+        build_version = ''
+
     return N_("""
         <br>
-            Git Cola version %(cola_version)s
+            Git Cola version %(cola_version)s %(build_version)s
         <ul>
             <li> %(platform_version)s
             <li> Python (%(python_path)s) %(python_version)s
@@ -217,24 +224,27 @@ def authors_text():
     palette = QtGui.QPalette()
     contact = N_('Email contributor')
     authors = (
-        dict(name='David Aguilar',
-             title=N_('Maintainer (since 2007) and developer'),
-             email=mailto('davvid@gmail.com', contact, palette)),
         # The names listed here are listed in the same order as
         # `git shortlog --summary --numbered --no-merges`
         # Please submit a pull request if you would like to include your
         # email address in the about screen.
         # See the `generate-about` script in the "todo" branch.
         # vim :read! ./Meta/generate-about
+        dict(name='David Aguilar',
+             title=N_('Maintainer (since 2007) and developer'),
+             email=mailto('davvid@gmail.com', contact, palette)),
         dict(name='Daniel Harding', title=N_('Developer')),
         dict(name='Ｖ字龍(Vdragon)', title=N_('Developer'),
              email=mailto('Vdragon.Taiwan@gmail.com', contact, palette)),
+        dict(name='Efimov Vasily', title=N_('Developer')),
         dict(name='Guillaume de Bure', title=N_('Developer')),
         dict(name='Alex Chernetz', title=N_('Developer')),
         dict(name='Uri Okrent', title=N_('Developer')),
-        dict(name='Thomas Kluyver', title=N_('Developer')),
         dict(name='Andreas Sommer', title=N_('Developer')),
+        dict(name='Thomas Kluyver', title=N_('Developer')),
         dict(name='Minarto Margoliono', title=N_('Developer')),
+        dict(name='Szymon Judasz', title=N_('Developer')),
+        dict(name='Javier Rodriguez Cuevas', title=N_('Developer')),
         dict(name='Igor Galarraga', title=N_('Developer')),
         dict(name='Stanislaw Halik', title=N_('Developer')),
         dict(name='Virgil Dupras', title=N_('Developer')),
@@ -242,7 +252,9 @@ def authors_text():
         dict(name='Stefan Naewe', title=N_('Developer')),
         dict(name='Ville Skyttä', title=N_('Developer')),
         dict(name='Benedict Lee', title=N_('Developer')),
+        dict(name='Filip Danilović', title=N_('Developer')),
         dict(name='Steffen Prohaska', title=N_('Developer')),
+        dict(name='xhl', title=N_('Developer')),
         dict(name='Michael Geddes', title=N_('Developer')),
         dict(name='Rustam Safin', title=N_('Developer')),
         dict(name='David Martínez Martí', title=N_('Developer')),
@@ -250,10 +262,13 @@ def authors_text():
         dict(name='Karl Bielefeldt', title=N_('Developer')),
         dict(name='Marco Costalba', title=N_('Developer')),
         dict(name='Michael Homer', title=N_('Developer')),
+        dict(name='Sebastian Schuberth', title=N_('Developer')),
         dict(name='Sven Claussner', title=N_('Developer')),
         dict(name='v.paritskiy', title=N_('Developer')),
+        dict(name='AJ Bagwell', title=N_('Developer')),
         dict(name='Adrien be', title=N_('Developer')),
         dict(name='Audrius Karabanovas', title=N_('Developer')),
+        dict(name='Barrett Lowe', title=N_('Developer')),
         dict(name='Ben Boeckel', title=N_('Developer')),
         dict(name='Boris W', title=N_('Developer')),
         dict(name='Charles', title=N_('Developer')),
@@ -267,8 +282,10 @@ def authors_text():
         dict(name='Iulian Udrea', title=N_('Developer')),
         dict(name='Jake Biesinger', title=N_('Developer')),
         dict(name='Jamie Pate', title=N_('Developer')),
+        dict(name='Jean-Francois Dagenais', title=N_('Developer')),
         dict(name='Karthik Manamcheri', title=N_('Developer')),
         dict(name='Kelvie Wong', title=N_('Developer')),
+        dict(name='Kyle', title=N_('Developer')),
         dict(name='Maciej Filipiak', title=N_('Developer')),
         dict(name='Maicon D. Filippsen', title=N_('Developer')),
         dict(name='Markus Heidelberg', title=N_('Developer')),
@@ -284,14 +301,13 @@ def authors_text():
         dict(name='Rolando Espinoza', title=N_('Developer')),
         dict(name="Samsul Ma'arif", title=N_('Developer')),
         dict(name='Sebastian Brass', title=N_('Developer')),
-        dict(name='Sebastian Schuberth', title=N_('Developer')),
         dict(name='Vaibhav Sagar', title=N_('Developer')),
         dict(name='Ved Vyas', title=N_('Developer')),
         dict(name='Voicu Hodrea', title=N_('Developer')),
         dict(name='Wesley Wong', title=N_('Developer')),
         dict(name='Wolfgang Ocker', title=N_('Developer')),
-        dict(name='ZH', title=N_('Developer')),
-        dict(name='aj-bagwell', title=N_('Developer')),
+        dict(name='Zhang Han', title=N_('Developer')),
+        dict(name='beauxq', title=N_('Developer')),
     )
     bug_url = 'https://github.com/git-cola/git-cola/issues'
     bug_link = link(bug_url, bug_url)
@@ -310,26 +326,31 @@ def translators_text():
     email = lambda addr: mailto(addr, contact, palette)
 
     translators = (
+        # See the `generate-about` script in the "todo" branch.
+        # vim :read! ./Meta/generate-about --translators
         dict(name='Ｖ字龍(Vdragon)',
              title=N_('Traditional Chinese (Taiwan) translation'),
              email=mailto('Vdragon.Taiwan@gmail.com', contact, palette)),
         dict(name='Vitor Lobo',
              title=N_('Brazilian translation')),
-        dict(name='Mickael Albertus',
-             title=N_('French translation')),
+        dict(name='Zhang Han',
+             title=N_('Simplified Chinese translation')),
+        dict(name='Igor Kopach',
+             title=N_('Ukranian translation')),
         dict(name='Minarto Margoliono',
              title=N_('Indonesian translation')),
-        dict(name='Zhang Han',
-             title=N_('Chinese translation')),
         dict(name='Sven Claussner',
              title=N_('German translation')),
         dict(name='Vaiz',
              title=N_('Russian translation')),
         dict(name='Barış ÇELİK',
              title=N_('Turkish translation')),
-        dict(name='Łukasz Wojniłowicz',
-             email=email('lukasz.wojnilowicz@gmail.com'),
-             title=N_('Polish translation')),
+        dict(name='Guo Yunhe',
+             title=N_('Simplified Chinese translation')),
+        dict(name='Mickael Albertus',
+             title=N_('French translation')),
+        dict(name='Pavel Rehak',
+             title=N_('Czech translation')),
         dict(name='Peter Dave Hello',
              title=N_('Traditional Chinese (Taiwan) translation')),
         dict(name='Pilar Molina Lopez',
@@ -338,8 +359,10 @@ def translators_text():
              title=N_('Indonesian translation')),
         dict(name='Zeioth',
              title=N_('Spanish translation')),
-        dict(name='Igor Kopach',
-             title=N_('Ukranian translation')),
+        dict(name='balping',
+             title=N_('Hungarian translation')),
+        dict(name='Łukasz Wojniłowicz',
+             title=N_('Polish translation')),
     )
 
     bug_url = 'https://github.com/git-cola/git-cola/issues'
